======
Blocks
======

Autodrive
---------
.. automodule:: crappy.blocks.autoDrive
   :members:

Camera
------
.. automodule:: crappy.blocks.camera
   :members:

Client Server
-------------
.. automodule:: crappy.blocks.client_server
   :members:

Dashboard
---------
.. automodule:: crappy.blocks.dashboard
   :members:

Discorrel
---------
.. automodule:: crappy.blocks.discorrel
   :members:

Displayer
---------
.. automodule:: crappy.blocks.displayer
   :members:

Disve
-----
.. automodule:: crappy.blocks.disve
   :members:

Drawing
-------
.. automodule:: crappy.blocks.drawing
   :members:

Fake machine
------------
.. automodule:: crappy.blocks.fake_machine
   :members:

Generator
---------
.. automodule:: crappy.blocks.generator
   :members:

generator path
++++++++++++++
There are several types of path available for the generator block.

.. automodule:: crappy.blocks.generator_path.path
   :members:

constant
""""""""
.. automodule:: crappy.blocks.generator_path.constant
   :members:

custom
""""""
.. automodule:: crappy.blocks.generator_path.custom
   :members:

cyclic ramp
"""""""""""
.. automodule:: crappy.blocks.generator_path.cyclic_ramp
   :members:

cyclic
""""""
.. automodule:: crappy.blocks.generator_path.cyclic
   :members:

inertia
"""""""
.. automodule:: crappy.blocks.generator_path.inertia
   :members:

protection
""""""""""
.. automodule:: crappy.blocks.generator_path.protection
   :members:

ramp
""""
.. automodule:: crappy.blocks.generator_path.ramp
   :members:

sine
""""
.. automodule:: crappy.blocks.generator_path.sine
   :members:

GPUCorrel
---------
.. automodule:: crappy.blocks.gpucorrel
   :members:

GPUve
-----
.. automodule:: crappy.blocks.gpuve
   :members:

Grapher
-------
.. automodule:: crappy.blocks.grapher
   :members:

GUI
---
.. automodule:: crappy.blocks.gui
   :members:

HDF Recorder
------------
.. automodule:: crappy.blocks.hdf_recorder
   :members:

IOBlock
-------
.. automodule:: crappy.blocks.ioblock
   :members:

Machine
-------
.. automodule:: crappy.blocks.machine
   :members:

Mean_block
----------
.. automodule:: crappy.blocks.mean
   :members:

Multiplex
---------
.. automodule:: crappy.blocks.multiplex
   :members:

PID
---
.. automodule:: crappy.blocks.pid
   :members:

Reader
------
.. automodule:: crappy.blocks.reader
   :members:

Recorder
--------
.. automodule:: crappy.blocks.recorder
   :members:

Sink
----
.. automodule:: crappy.blocks.sink
   :members:

UController
-----------
.. automodule:: crappy.blocks.ucontroller
   :members:

VideoExtenso
------------
.. automodule:: crappy.blocks.videoExtenso
   :members:
